package thyyxxk.webserver.controller.medicalinsurance.costcontrol;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import thyyxxk.webserver.entity.ResultVo;
import thyyxxk.webserver.service.medicalinsurance.costcontrol.YbUtilService;

import java.util.List;
import java.util.Map;

/**
 * @ClassName YbUtilController
 * @Description 医保报表常用工具类
 * @Author hsh
 * @Date 2022/8/9 16:19
 **/
@RestController
@RequestMapping("/ybUtil")
public class YbUtilController {

    private final YbUtilService service;

    @Autowired
    public YbUtilController(YbUtilService service) {
        this.service = service;
    }

    @PostMapping("/selectSmallDept")
    public ResultVo<List<Map<String, Object>>> selectSmallDept(@RequestBody @Validated Map<String, String> map){
        return service.selectSmallDept(map);
    }

    @PostMapping("/selectDoctor")
    public ResultVo<List<Map<String, Object>>> selectDoctor(@RequestBody @Validated Map<String, String> map){
        return service.selectDoctor(map);
    }

    @PostMapping("/selectAllSmallDept")
    public ResultVo<List<Map<String, Object>>> selectAllSmallDept(@RequestBody @Validated Map<String, String> map){
        return service.selectAllSmallDept(map);
    }

    @PostMapping("/selectAllDoctor")
    public ResultVo<List<Map<String, Object>>> selectAllDoctor(@RequestBody @Validated Map<String, String> map){
        return service.selectAllDoctor(map);
    }

    @PostMapping("/selectAllDept")
    public ResultVo<List<Map<String, Object>>> selectAllDept(@RequestBody @Validated Map<String, String> map){
        return service.selectAllDept(map);
    }

    @PostMapping("/selectAllRegLevel")
    public ResultVo<List<Map<String, Object>>> selectAllRegLevel(@RequestBody @Validated Map<String, String> map){
        return service.selectAllRegLevel(map);
    }

    @PostMapping("/selectQxSmallDept")
    public ResultVo<List<Map<String, Object>>> selectQxSmallDept(@RequestBody @Validated Map<String, String> map){
        return service.selectQxSmallDept(map);
    }

}
